@@ -143,7 +143,8 @@ class DeliciousBookmark():
         if include == 'time' and human_readable:
             return str(datetime.strptime(value, '%Y-%m-%dT%H:%M:%SZ'))
         elif include == 'bookmark':
-            return 'http://delicious.com/save?url=%s' % quote(value)
+            return 'http://delicious.com/save?url=%s&noui=1&jump=doclose' \
+                   % quote(value)
         else:
             return value
 
